@@ -69,6 +69,7 @@ movebank_tag_type_table <- structure(
 
 
 movebank_spatial_column_pairs <- list(
+  lora_gateway_location = c("lora_gateway_longitude", "lora_gateway_latitude"),
   argos_location_1 = c("argos_lon1", "argos_lat1"),
   argos_location_2 = c("argos_lon2", "argos_lat2"),
   birth_location = c("birth_longitude", "birth_latitude"),
@@ -151,7 +152,7 @@ mb_column_units <- c(
   "gps:tdop" = "1",
   "gps:vdop" = "1",
   "ground-speed" = "m/s",
-  "gsm:gsm-signal-strength" = "ASU", # arbitrary strength units
+  #  "gsm:gsm-signal-strength" = "ASU", # arbitrary strength units
   "gt:sys-week" = "count",
   "gt:tx-count" = "count",
   "gyroscope-sampling-frequency-per-axis" = "Hz",
@@ -199,7 +200,7 @@ mb_column_units <- c(
   "sigfox:tx-interval" = "min",
   "solar-cell-voltage" = "mV",
   "solar-voltage-percent" = "%",
-  "speed-accuracy" = "m",
+  "speed-accuracy" = "m/s",
   "tag-backup-voltage" = "mV",
   "tag-beacon-frequency" = "MHz",
   "tag-mass-total" = "g",
@@ -233,6 +234,13 @@ mb_column_units <- c(
   "weight" = "g",
   "wet-count" = "count",
   "zero-crossings-steps" = "count",
+  `battery-charging-voltage` = "mV", `geolocation-station-count` = "count",
+  `gnss:dop` = "1", `gnss:hdop` = "1", `gnss:maximum-signal-strength` = "dBm",
+  `gnss:message-count` = "count", `gnss:pdop` = "1", `gnss:satellite-count` = "count",
+  `gnss:time-to-fix` = "s", `gnss:vdop` = "1",
+  `lora:rssi` = "dBm", `lora:snr` = "dB", `lora:uplink-count` = "count",
+  `opencollar:cold-retry` = "count", `opencollar:hot-retry` = "count",
+  `opencollar:msg` = "count", `opencollar:uptime` = "weeks",
   NULL
 )
 movebank_column_types <- list(
@@ -773,6 +781,65 @@ movebank_column_types <- list(
   "wildfi-record-type" = col_factor(),
   "zero-crossings-amplitude" = col_double(),
   "zero-crossings-steps" = col_integer(),
+  `awt:alarms-battery` = col_logical(),
+  `awt:alarms-cbit` = col_logical(),
+  `awt:alarms-coverage` = col_logical(),
+  `awt:alarms-geofence` = col_logical(),
+  `awt:alarms-memory` = col_logical(),
+  `awt:alarms-movement` = col_logical(),
+  `awt:alarms-tamperfoil` = col_logical(),
+  `awt:alarms-track-mode` = col_logical(),
+  `awt:log-interval` = col_factor(
+    ordered = T,
+    levels = c(
+      "every 10 minutes", "every 30 minutes", "every 1 hour", "every 2 hours", "every 3 hours", "every 4 hours",
+      "every 5 hours", "every 6 hours", "every 8 hours", "every 12 hours", "every 24 hours", "every 48 hours", "off"
+    )
+  ),
+  `battery-charging-voltage` = col_logical(),
+  `breed-stage` = col_character(),
+  `druid:alert` = col_factor(levels = 1),
+  `druid:data-source` = col_factor(levels = c("[1]", "[2]", "[4]", "[8]", "[10]", "[100]", "[101]")),
+  `geolocation-station-count` = col_integer(),
+  `gnss:dop` = col_double(),
+  `gnss:fix-type` = col_factor(ordered = TRUE, levels = 1:3),
+  `gnss:fix-type-raw` = col_factor(),
+  `gnss:hdop` = col_double(),
+  `gnss:maximum-signal-strength` = col_double(),
+  `gnss:message-count` = col_integer(),
+  `gnss:pdop` = col_double(),
+  `gnss:satellite-count` = col_integer(),
+  `gnss:time-to-fix` = col_double(),
+  `gnss:vdop` = col_double(),
+  `lora:data-rate` = col_double(),
+  `lora:gateway-id` = col_factor(),
+  `lora:gateway-latitude` = col_double(),
+  `lora:gateway-longitude` = col_double(),
+  `lora:payload` = col_character(),
+  `lora:port` = col_integer(),
+  `lora:rssi` = col_double(),
+  `lora:snr` = col_integer(),
+  `lora:spreading-factor` = col_double(),
+  `lora:uplink-count` = col_integer(),
+  `opencollar:active-tracking` = col_logical(),
+  `opencollar:cold-retry` = col_integer(),
+  `opencollar:error-acc` = col_logical(),
+  `opencollar:error-bat` = col_logical(),
+  `opencollar:error-ble` = col_logical(),
+  `opencollar:error-flash` = col_logical(),
+  `opencollar:error-lr` = col_logical(),
+  `opencollar:error-lr-join` = col_logical(),
+  `opencollar:error-ublox` = col_logical(),
+  `opencollar:error-ublox-fix` = col_logical(),
+  `opencollar:hot-retry` = col_integer(),
+  `opencollar:locked` = col_logical(),
+  `opencollar:msg` = col_integer(),
+  `opencollar:payload-type` = col_factor(),
+  `opencollar:reset` = col_integer(),
+  `opencollar:uptime` = col_double(),
+  `opencollar:ver-fw-major` = col_factor(),
+  `opencollar:ver-fw-minor` = col_factor(),
+  `opencollar:ver-fw-type` = col_factor(),
   NULL
 ) # add null so it is easy to sort the list (all have comma at end)
 
