@@ -4,11 +4,13 @@
 #' @importFrom assertthat has_name has_attr
 #' @importFrom sf st_as_sf st_crs
 #' @importFrom units set_units as_units
+#' @importFrom utils unzip
 NULL
 
 #' Reading files downloaded from movebank
 #'
-#' @param file The file path to read or a R connection (for details see \code{\link[base]{connections}})
+#' @param file The file path to read or a R connection (for details see \code{\link[base]{connections}}).
+#' Files can either be csv files from movebank or zip files that are created using Env-DATA.
 #'
 #' @param ... Arguments passed on to \code{\link[vroom]{vroom}}, for example `col_select`
 #'
@@ -34,7 +36,7 @@ NULL
 #' @export
 #' @examples
 #' path_fishers <- mt_example()
-  #' @examplesIf vroom:::vroom_threads() < 9
+#' @examplesIf parallel::detectCores() < 9
 #' mt_read(path_fishers)
 #'
 #' ## Reduce the mount of data read this might provide memory advantages
@@ -43,8 +45,17 @@ NULL
 #'   "location-long", "location-lat",
 #'   "timestamp", "individual-local-identifier"
 #' ))
+#' ## Read Galapagos Albatross data that has been annotated
+#' mt_read(mt_example("Galapagos_Albatrosses-1332012225316982996.zip"))
+#' ## Notice this produces a warning as some units are not recognized
+#' ## This can be prevented by installing the units
+#' \dontrun{
+#' units::install_unit("gC", "g", "Grams of carbon")
+#' }
 #'
 #' \dontrun{
+#' ## Reading can also be manipulted to speed up or reduce memory consumption
+#' ## Here we assume the Galapagos albatross data has been downloaded
 #' mt_read("~/Downloads/Galapagos Albatrosses.csv")
 #' ## Exclude the column 'eobs:accelerations-raw'
 #' mt_read("~/Downloads/Galapagos Albatrosses.csv",
@@ -55,6 +66,46 @@ NULL
 #' mt_read(pipe('cat "~/Downloads/Galapagos Albatrosses.csv" | grep "2008-07\\|time"'))
 #' }
 mt_read <- function(file, ...) {
+  if (is_scalar_character(file) && grepl("\\.zip$", file)) {
+    f <- grep("csv$", unzip(file, list = T)$Name, value = T)
+    assert_that(is_scalar_character(f), msg = "Env-DATA zipfiles are only expected to contain one csv file")
+    data <- mt_read(unz(file, f), ...)
+
+    readme <- vroom::vroom_lines(unz(file, "readme.txt"))
+    readme_vars <- split(readme, cumsum(grepl("^Name: ", readme)))[-1]
+    var_names <- sub("Name: ", "", unlist(lapply(readme_vars, head, n = 1)))
+    if (!all(s <- var_names %in% colnames(data))) {
+      cli_warn(
+        c(
+          "There{qty(sum(!s))} {?is/are} {sum(!s)} column{?s} in {.file readme.txt} that are not the csv.",
+          "These are: {.var {var_names[!s]}}"
+        ),
+        class = "move2_warning_no_match_csv_readme"
+      )
+    }
+    if (length(s <- setdiff(colnames(data), c(var_names, names(movebank_column_types), "geometry")))) {
+      cli_warn(c("There {qty(length(s))}{?is/are} {length(s)} column{?s} in the csv that {?is/are} not in {.file readme.txt} or the movebank vocabulary. {?This is/These are}: {.var {s}}"),
+        class = "move2_warning_no_match_for_vocabulary"
+      )
+    }
+    units <- lapply(readme_vars, grep, pattern = "^Unit: ", value = T) |>
+      unlist() |>
+      sub(pattern = "^Unit: ", replacement = "")
+    names(units) <- var_names
+    units_list <- lapply(units, function(x) try(as_units(x), silent = T))
+
+    if (any(ss <- unlist(lapply(units_list, inherits, "try-error")))) {
+      cli_warn("The following {qty((unique(units[ss])))}unit{?s} {?is/are} not parsible: {.var {(unique(units[ss]))}}.
+           Th{?is/ese} belong{?s/} to: {.var {names(units[ss])}}.
+           Therefore these variables will not have units defined.",
+        class = "move2_warning_unparsable_units_reading"
+      )
+    }
+    for (i in which(!ss)) {
+      data[[names(units_list)[i]]] <- set_units(data[[names(units_list)[i]]], units_list[[i]], mode = "standard")
+    }
+    return(data)
+  }
   data <- suppressWarnings(
     classes = "vroom_mismatched_column_name",
     vroom::vroom(file, delim = ",", ..., col_types = movebank_column_types)
@@ -127,13 +178,18 @@ mt_read <- function(file, ...) {
 
 #' Get path to `move2` example data
 #'
-#' The `move2` package comes with an example data file that is directly downloaded from
-#' \href{https://www.movebank.org}{movebank} and gz compressed for reduction in package size.
+#' The `move2` package comes with an example data files that is directly downloaded from
+#' \href{https://www.movebank.org}{movebank}.
 #'
-#' @details The example dataset is the study "Martes pennanti LaPoint New York" (study id: `69258089`), shared under
+#' @param file The name of the file for which the path needs to be retrieved.
+#' @details The fisher example dataset is the study "Martes pennanti LaPoint New York" (study id: `69258089`), shared under
 #'  the CC-BY-NC license.
-#' For more information on the data see LaPoint et al. (2013) Landscape Ecology. doi: 10.1007/s10980-013-9910-0
+#' For more information on the data see LaPoint et al. (2013) Landscape Ecology. doi: 10.1007/s10980-013-9910-0 .
+#' This csv file is gz compressed for reduction in package size.
 #'
+#' The Galapagos Albatrosses (study id: `2911040`) dataset annotated with environmental data using the Env-DATA system.
+#' For this dataset two individuals (`4261-2228` & `2131-2131`) were selected. Data was annotated with wind and
+#' an productivity variables.
 #' @export
 #' @return The path to the example file of the `move2` package
 #' @seealso
@@ -142,8 +198,8 @@ mt_read <- function(file, ...) {
 #'
 #' ## Get path to one example
 #' mt_example()
-#' mt_read(mt_example())
-mt_example <- function() {
-  path <- "fishers.csv.gz"
-  system.file("extdata", path, package = "move2", mustWork = TRUE)
+#' mt_example("Galapagos_Albatrosses-1332012225316982996.zip")
+mt_example <- function(file = c("fishers.csv.gz", "Galapagos_Albatrosses-1332012225316982996.zip")) {
+  file <- rlang::arg_match(file)
+  system.file("extdata", file, package = "move2", mustWork = TRUE)
 }
